@@ -157,9 +157,9 @@ void SELF_BLEU_CPP::get_max_counts(int n)
 
     vector<int>::iterator max_val_ptr;
     string ng;
-    // #pragma omp parallel
+    #pragma omp parallel
     {
-        // #pragma omp for schedule(guided) private(max_val_ptr, ng)
+        #pragma omp for schedule(guided) private(max_val_ptr, ng)
         for (int i = 0; i < (int)ngrams_set_list.size(); i++)
         {
             ng = ngrams_set_list.at(i);
